# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.1.11] - 2020-05-21
### Updated
- Remove advanced manager from commons

## [1.1.10] - 2020-05-19
### Added
- Config constants

## [1.1.9] - 2020-05-19
### Added
- OctoBot channels initialization

## [1.1.8] - 2020-05-18
### Added
- run_in_bot_async_executor util function

## [1.1.7] - 2020-05-17
### Fixed
- Bot interface config command

## [1.1.6] - 2020-05-16
### Updated
- Requirements

## [1.1.5] - 2020-05-15
### Updated
- OctoBot requirements

## [1.1.4] - 2020-05-10
### Updated
- Stop interface
- Telegram requirement

## [1.1.3] - 2020-05-10
### Updated
- Channel requirement
- Commons requirement
- Trading requirement

## [1.1.2] - 2020-05-06
### Added
- [Service] Webhook

## [1.1.1] - 2020-05-03
### Added
- Can now edit user config in services

## [1.1.0] - 2020-05-02
### Updated
- Octobot backtesting import paths

## [1.0.8] - 2020-05-01
### Added
- Include interfaces and notifications

## [1.0.7] - 2020-05-01
### Updated
- Handle multiple services for service feeds and interfaces

## [1.0.6] - 2020-04-17
### Updated
- python-telegram-bot requirement

## [1.0.5] - 2020-04-13
### Added
- ENV_WEB_ADDRESS environment constant

## [1.0.4] - 2020-04-13
### Added
- WEB_PORT environment constant

## [1.0.3] - 2020-04-10
### Added
- get_backtesting_service_feed api
- Service feed handling

## [1.0.2] - 2020-04-04
### Update
- Requirements version

### Fixed
- Travis CI file

## [1.0.1] - 2020-11-02
### Added
- Version update

## [1.0.0] - 2020-01-02
### Added
- Services
- Service-feeds
